/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

use thiserror::Error;

#[derive(Debug, Error)]
pub enum McpRuntimeError {
    #[error("Failed to create service")]
    FailedToCreateService,
    #[error("Failed to start HTTP server")]
    FailedToStartHttpServer,
    #[error("Iggy client error")]
    IggyClient(#[from] iggy::prelude::ClientError),
    #[error("Iggy error")]
    IggyError(#[from] iggy::prelude::IggyError),
    #[error("Missing Iggy credentials")]
    MissingIggyCredentials,
    #[error("Missing TLS certificate file")]
    MissingTlsCertificateFile,
    #[error("Failed to create Iggy consumer ID")]
    FailedToCreateConsumerId,
    #[error("Invalid API path")]
    InvalidApiPath,
    #[error("Token file not found: {0}")]
    TokenFileNotFound(String),
    #[error("Failed to read token file '{0}': {1}")]
    TokenFileReadError(String, String),
    #[error("Token file is empty: {0}")]
    TokenFileEmpty(String),
}
